# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation.numerics as windows_foundation_numerics
import winrt.windows.perception.spatial as windows_perception_spatial

Self = typing.TypeVar('Self')

@typing.final
class HolographicKeyboard_Static(type):
    def get_default(cls) -> typing.Optional[HolographicKeyboard]: ...

@typing.final
class HolographicKeyboard(winrt.system.Object, metaclass=HolographicKeyboard_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> HolographicKeyboard: ...
    def reset_placement_override(self) -> None: ...
    @typing.overload
    def set_placement_override(self, coordinate_system: typing.Optional[windows_perception_spatial.SpatialCoordinateSystem], top_center_position: windows_foundation_numerics.Vector3, orientation: windows_foundation_numerics.Quaternion, /) -> None: ...
    @typing.overload
    def set_placement_override(self, coordinate_system: typing.Optional[windows_perception_spatial.SpatialCoordinateSystem], top_center_position: windows_foundation_numerics.Vector3, orientation: windows_foundation_numerics.Quaternion, max_size: windows_foundation_numerics.Vector2, /) -> None: ...

